Documentation
¶
Index ¶
- func Description(path string) string
- type Git
- func (r *Git) Blame(file string) (string, error)
- func (r *Git) Branches() ([]*plumbing.Reference, error)
- func (r *Git) ByteContent(path string) ([]byte, error)
- func (r *Git) Commits() ([]*object.Commit, error)
- func (r *Git) Description() string
- func (r *Git) FileContent(path string) (string, bool, error)
- func (r *Git) FileTree() (*object.Tree, error)
- func (r *Git) Head() string
- func (r *Git) IsSymlink(path string) bool
- func (r *Git) LastCommit() (*object.Commit, error)
- func (r *Git) Patch(ctx context.Context, commit *object.Commit) (string, error)
- func (r *Git) PrimaryBranch() (*plumbing.Reference, error)
- func (r *Git) Tags() ([]*object.Tag, error)
- func (r *Git) UpdateServerInfo() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Description ¶
Description returns the description of that repository at path, if it was altered.
Types ¶
type Git ¶
type Git struct {
// contains filtered or unexported fields
}
Git holds basic repository data
func (*Git) ByteContent ¶
ByteContent returns the content of path.
func (*Git) Description ¶
Description returns the description of the related git repository, if it was altered.
func (*Git) FileContent ¶
FileContent returns the contant of path if it is not a binary type.
func (*Git) LastCommit ¶
LastCommit returns the last commit in that revision of that related git repository.
func (*Git) PrimaryBranch ¶
PrimaryBranch returns either main/master or the first branch available.
func (*Git) UpdateServerInfo ¶
UpdateServerInfo for the given repository. This is used by git http transport (dumb) to generate a list of available refs for the repository. https://git-scm.com/docs/git-update-server-info Needs create/read/write access to repo paths: objects/info/packs and info/refs